==> gridstack-8.x-2.6.tar.gz: gridstack/js/components/gridstack.parallax.js <==
/**
 * @file
 * Provides dead-simple parallax utilities.
 */

(function (Drupal, _db, Bio) {

  'use strict';

  var _hit = 0;

  Drupal.gridstack = Drupal.gridstack || {};

  /**
   * GridStack front-end public methods.
   *
   * @namespace
   */
  Drupal.gridstack.parallax = {
    bio: null,
    count: 0,
    items: [],
    options: {},
    animSelector: '.b-gs:not(.media--loading)',

    onObserving: function (entry, observer, options) {
      var me = this;
      var el = entry.target;

      // Element enters the visible area of its parent element.
      if (entry.isIntersecting) {
        el.classList.remove('is-gs-hidden');
        el.classList.add('is-gs-visible');

        // Bio is only executed once, destroy and reinit to keep observing.
        if (_hit === (me.count - 1)) {
          _hit = 0;
          me.bio.disconnect(true);
          me.bio.reinit();
        }

        _hit++;
      }
      else {
        el.classList.add('is-gs-hidden');
        el.classList.remove('is-gs-visible', 'is-gs-transitioned');
      }
    }

  };

  /**
   * GridStack utility functions.
   *
   * @param {HTMLElement} elm
   *   The .is-gs-parallax container.
   */
  function doParallax(elm) {
    var me = Drupal.gridstack.parallax;

    if (elm.classList.contains('is-gs-parallax-fs')) {
      document.body.classList.add('is-gs-parallax-fs-body');
    }

    me.options = {
      root: elm,
      observing: me.onObserving.bind(me),
      selector: '.box__content'
    };

    me.items = elm.querySelectorAll(me.options.selector);
    me.count = me.items.length;

    if (me.count === 0) {
      return;
    }

    var onTransitionStart = function (e) {
      var el = e.target;
      var cn = _db.closest(el, me.options.selector) || el;

      cn.classList.add('is-gs-transitioning');
    };

    var onTransitionEnd = function (e) {
      var el = e.target;
      var cn = _db.closest(el, me.options.selector) || el;

      cn.classList.remove('is-gs-transitioning');
      cn.classList.add('is-gs-transitioned');

      cn.removeEventListener('transitionend', onTransitionEnd);
      cn.removeEventListener('transitionstart', onTransitionStart);
    };

    _db.forEach(me.items, function (item) {
      var bg = item.querySelector('.b-gs');

      if (bg !== null) {
        bg.style.minHeight = (item.offsetHeight + 120) + 'px';

        _db.on(item, 'transitionstart', me.animSelector, Drupal.debounce(onTransitionStart, 100));
        _db.on(item, 'transitionend', me.animSelector, Drupal.debounce(onTransitionEnd, 100));
      }
    });

    if ('IntersectionObserver' in window) {
      me.bio = new Bio(me.options);
      elm.classList.add('is-gs-parallax-on');
    }
  }

  /**
   * Attaches behavior to HTML element identified by .is-gs-parallax.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.gridStackParallax = {
    attach: function (context) {
      context = context || document;
      if ('length' in context) {
        context = context[0];
      }

      var elms = context.querySelectorAll('.is-gs-parallax');
      if (elms.length > 0) {
        _db.once(_db.forEach(elms, doParallax, context));
      }
    }
  };

})(Drupal, dBlazy, Bio);

==> gridstack-8.x-2.7.tar.gz: gridstack/js/components/gridstack.parallax.js <==
/**
 * @file
 * Provides dead-simple parallax utilities.
 */

(function (Drupal, _db, Bio) {

  'use strict';

  var _hit = 0;

  Drupal.gridstack = Drupal.gridstack || {};

  /**
   * GridStack front-end public methods.
   *
   * @namespace
   */
  Drupal.gridstack.parallax = {
    bio: null,
    count: 0,
    items: [],
    options: {},
    animSelector: '.b-gs:not(.media--loading):not(.is-b-loading)',

    onObserving: function (entry, observer, options) {
      var me = this;
      var el = entry.target;

      // Element enters the visible area of its parent element.
      if (entry.isIntersecting) {
        el.classList.remove('is-gs-hidden');
        el.classList.add('is-gs-visible');

        // Bio is only executed once, destroy and reinit to keep observing.
        if (_hit === (me.count - 1)) {
          _hit = 0;
          me.bio.disconnect(true);
          me.bio.reinit();
        }

        _hit++;
      }
      else {
        el.classList.add('is-gs-hidden');
        el.classList.remove('is-gs-visible', 'is-gs-transitioned');
      }
    }

  };

  /**
   * GridStack utility functions.
   *
   * @param {HTMLElement} elm
   *   The .is-gs-parallax container.
   */
  function doParallax(elm) {
    var me = Drupal.gridstack.parallax;

    if (elm.classList.contains('is-gs-parallax-fs')) {
      document.body.classList.add('is-gs-parallax-fs-body');
    }

    me.options = {
      root: elm,
      observing: me.onObserving.bind(me),
      selector: '.box__content'
    };

    me.items = elm.querySelectorAll(me.options.selector);
    me.count = me.items.length;

    if (me.count === 0) {
      return;
    }

    var onTransitionStart = function (e) {
      var el = e.target;
      var cn = _db.closest(el, me.options.selector) || el;

      cn.classList.add('is-gs-transitioning');
    };

    var onTransitionEnd = function (e) {
      var el = e.target;
      var cn = _db.closest(el, me.options.selector) || el;

      cn.classList.remove('is-gs-transitioning');
      cn.classList.add('is-gs-transitioned');

      cn.removeEventListener('transitionend', onTransitionEnd);
      cn.removeEventListener('transitionstart', onTransitionStart);
    };

    _db.forEach(me.items, function (item) {
      var bg = item.querySelector('.b-gs');

      if (bg !== null) {
        bg.style.minHeight = (item.offsetHeight + 120) + 'px';

        _db.on(item, 'transitionstart', me.animSelector, Drupal.debounce(onTransitionStart, 100));
        _db.on(item, 'transitionend', me.animSelector, Drupal.debounce(onTransitionEnd, 100));
      }
    });

    if ('IntersectionObserver' in window) {
      me.bio = new Bio(me.options);
      elm.classList.add('is-gs-parallax-on');
    }
  }

  /**
   * Attaches behavior to HTML element identified by .is-gs-parallax.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.gridStackParallax = {
    attach: function (context) {
      context = context || document;
      if ('length' in context) {
        context = context[0];
      }

      var elms = context.querySelectorAll('.is-gs-parallax');
      if (elms.length > 0) {
        _db.once(_db.forEach(elms, doParallax, context));
      }
    }
  };

})(Drupal, dBlazy, Bio);
